mpservice
=========

The package ``mpservice`` provides classes for serving, stream processing, and some related utilities.
The central theme is concurrency by threads or processes.

Read the `documentation <https://mpservice.readthedocs.io/en/latest/>`_.

To install, do

::
    
    python3 -m pip install mpservice


Status
------

Production ready. Under active development.


Python version
--------------

Development and testing were conducted in Python 3.8 until version 0.12.0.
Starting with 0.12.1, development and testing happen in Python 3.10.
Code continues to NOT intentionally use features beyond Python 3.8.
I intend to test agsint versions 3.8, 3.9, 3.10, 3.11 once I find time to set that up.
